tiled.queries.NotEq
===================

.. currentmodule:: tiled.queries

.. autoclass:: NotEq

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~NotEq.__init__
      ~NotEq.decode
      ~NotEq.encode
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~NotEq.key
      ~NotEq.value
   
   